@@ -2,9 +2,12 @@
 Keccak
 
 Keccak hash function.
+
+Note:   Keccak is different from standard SHA3
+        So the haslib.sha3_256() cannot be used to compute keccak_256()
 '''
 
-import sha3  # pysha3
+from eth_hash.auto import keccak
 from typing import List, Tuple
 
 
@@ -22,8 +25,9 @@ def keccak256(list_of_bytes: List[bytes]) -> Tuple[bytes, int]:
     Tuple[bytes, int]
         Hash value in bytes and length of bytes.
     '''
-    m = sha3.keccak_256()
+    m = keccak.new(b'')
     for item in list_of_bytes:
         m.update(item)
 
-    return m.digest(), m.digest_size
+    _digest = m.digest()
+    return _digest, len(_digest)
\ No newline at end of file
