@@ -10,7 +10,7 @@ Derive the correct seed for BIP32.
 
 from typing import List
 from mnemonic import Mnemonic
-from bip_utils import Bip32
+from retro_bip_utils import Bip32
 
 # BIP-44 specified path notation:
 # m / purpose' / coin_type' / account' / change / address_index
